function [residual, g1, g2, g3] = cycle_irf_dynamic(y, x, params, steady_state, it_)
%
% Status : Computes dynamic model for Dynare
%
% Inputs :
%   y         [#dynamic variables by 1] double    vector of endogenous variables in the order stored
%                                                 in M_.lead_lag_incidence; see the Manual
%   x         [M_.exo_nbr by nperiods] double     matrix of exogenous variables (in declaration order)
%                                                 for all simulation periods
%   params    [M_.param_nbr by 1] double          vector of parameter values in declaration order
%   it_       scalar double                       time period for exogenous variables for which to evaluate the model
%
% Outputs:
%   residual  [M_.endo_nbr by 1] double    vector of residuals of the dynamic model equations in order of 
%                                          declaration of the equations
%   g1        [M_.endo_nbr by #dynamic variables] double    Jacobian matrix of the dynamic model equations;
%                                                           rows: equations in order of declaration
%                                                           columns: variables in order stored in M_.lead_lag_incidence
%   g2        [M_.endo_nbr by (#dynamic variables)^2] double   Hessian matrix of the dynamic model equations;
%                                                              rows: equations in order of declaration
%                                                              columns: variables in order stored in M_.lead_lag_incidence
%   g3        [M_.endo_nbr by (#dynamic variables)^3] double   Third order derivative matrix of the dynamic model equations;
%                                                              rows: equations in order of declaration
%                                                              columns: variables in order stored in M_.lead_lag_incidence
%
%
% Warning : this file is generated automatically by Dynare
%           from model file (.mod)

%
% Model equations
%

residual = zeros(83, 1);
T53 = params(2)*exp(y(103))/exp(y(49));
T89 = (1-params(6))/params(6)*exp(y(27))*1/(1-y(67));
T116 = exp(y(55))*exp(y(21))^params(20)*exp(y(1))^params(10);
T120 = exp(y(11))^(1-params(10));
T133 = exp(y(39));
T162 = exp(y(45))/exp(y(17));
T182 = exp(y(103))/exp(y(49));
T209 = exp(.5*(params(14)-exp(y(37)))/(exp(y(37))*params(14)*params(15)));
T229 = 1/T133*exp(y(30))/exp(y(37));
T249 = y(64)*exp(y(45))*exp(y(22))*exp(y(37))/(1-exp(y(22)));
T267 = 1-params(12)/2*y(34)^2;
T289 = exp(y(15))/exp(y(2));
T292 = exp(y(33))*(T267-params(12)*y(34)*T289);
T299 = exp(y(93))/exp(y(15));
T302 = exp(y(98))*T53*params(12)*y(99)*T299^2;
T351 = exp(y(96))*(1-exp(y(94)))*T182*params(2)*(1-params(5))*(1-params(13))*exp(y(19));
T359 = exp(y(45))*exp(y(38))/exp(y(17));
T407 = params(20)*params(9)^2;
T417 = (-0.5)*params(11)^0.5*exp(params(20)*0.5*(2*params(8)+T407)/(1-2*params(10)+params(10)^2));
T433 = 0.7071067811865475/params(9)*(params(8)+T407+(-log(exp(y(16))))+params(10)*log(exp(y(16)))-params(10)*params(8))/((-1)+params(10));
T453 = exp(params(10)*params(8)*(-params(20))/((-1)+params(10))^2);
T455 = T417*(erf(T433)-erf(0.7071067811865475*(params(8)+T407+(-10000000000)+params(10)*10000000000-params(10)*params(8))/params(9)/((-1)+params(10))))*T453/params(11)^0.5;
T475 = exp(y(43))*(1-params(10))*exp(y(32))/exp(y(11));
T478 = exp(y(16))/exp(y(21));
T487 = exp(y(43))*params(10)*exp(y(32))/exp(y(1));
T631 = params(6)/(1-params(6));
T636 = exp(y(19))*y(64)*exp(y(103))*params(2)*(1-params(5))*(1-params(13))/exp(y(49));
T686 = (exp(y(44))+T162)*exp(y(38));
T864 = (-(exp(y(15))*exp(y(2))))/(exp(y(2))*exp(y(2)));
T914 = (-(exp(y(45))*exp(y(17))))/(exp(y(17))*exp(y(17)));
T1067 = (-(params(2)*exp(y(103))*exp(y(49))))/(exp(y(49))*exp(y(49)));
T1072 = (-(exp(y(103))*exp(y(49))))/(exp(y(49))*exp(y(49)));
lhs =y(47);
rhs =log(exp(y(10)));
residual(1)= lhs-rhs;
lhs =y(48);
rhs =y(47)+params(2)*y(102);
residual(2)= lhs-rhs;
residual(3) = (-exp(y(45)))+(1-params(5))*(1-exp(y(22)))*exp(y(7))+(1-params(5))*(1-exp(y(22)))*exp(y(3))*exp(y(6));
residual(4) = (-params(17))/exp(y(17))+(1-params(5))*(1-params(13))*T53*((1-exp(y(94)))*exp(y(95))-exp(y(94))*y(64));
residual(5) = (-exp(y(51)))+exp(y(29))-params(17)/exp(y(17))-y(64);
residual(6) = (-exp(y(26)))+T89;
residual(7) = (-exp(y(29)))+exp(y(13))-params(6)*(exp(y(23))-exp(y(51)));
residual(8) = (-exp(y(43)))+T116*T120;
residual(9) = params(17)/exp(y(17))-exp(y(79));
residual(10) = (-exp(y(36)))+T133*exp(y(42))-exp(y(45))*exp(y(13))-params(17)*exp(y(44))-exp(y(24))*exp(y(46))-y(64)*exp(y(45))*exp(y(22))/(1-exp(y(22)));
residual(11) = (-exp(y(35)))+params(18)+y(65)+params(17)*(exp(y(44))+T162);
residual(12) = (-exp(y(42)))+exp(y(43))/exp(y(37));
residual(13) = (-T133)+exp(y(41))*exp(y(32));
residual(14) = (-exp(y(35)))+params(2)*(1-params(13))*T182*(exp(y(100))+exp(y(101)));
residual(15) = (-exp(y(37)))+(1-params(13))*(exp(y(4))+exp(y(5)));
residual(16) = (-1)+T133*T209;
residual(17) = (-exp(y(41)))+exp(y(40))/(exp(y(40))-1);
residual(18) = (-exp(y(40)))+1+exp(y(37))*params(15);
residual(19) = (-exp(y(42)))+T229;
residual(20) = (-exp(y(30)))+exp(y(53))+exp(y(15))+params(17)*exp(y(12))+(params(18)+y(65))*exp(y(38))+T249+exp(y(66));
residual(21) = (-exp(y(14)))+exp(y(1))*(1-params(19))+exp(y(15))*T267;
residual(22) = (-exp(y(33)))+T53*(exp(y(97))*(1-y(68))+(1-params(19))*exp(y(98)));
residual(23) = (-1)+T292+T302;
residual(24) = T289-y(34)-1;
residual(25) = (-exp(y(49)))+params(2)*exp(y(103))*(1+exp(y(78)));
residual(26) = (1-params(5))*(1-params(13))*T53*((1-exp(y(94)))*exp(y(95))-exp(y(94))*y(104))+exp(y(23))-exp(y(25))-exp(y(13));
residual(27) = (-exp(y(27)))+(1-y(67))*exp(y(13))-exp(y(28))+(1-params(5))*(1-params(13))*T53*(1-exp(y(94)))*exp(y(96));
residual(28) = (-exp(y(28)))+params(23)+y(63)+T351;
residual(29) = (-exp(y(12)))+exp(y(44))*(exp(y(37))+exp(y(38)))+T359;
residual(30) = (-exp(y(45)))+exp(y(11))/exp(y(37));
residual(31) = (-exp(y(46)))+exp(y(1))/exp(y(37));
residual(32) = (-exp(y(18)))+params(16)*exp(y(12))^(1-params(7))*exp(y(20))^params(7);
residual(33) = 1-exp(y(20))-exp(y(11));
residual(34) = (-exp(y(19)))+exp(y(18))/exp(y(20));
residual(35) = (-exp(y(17)))+exp(y(18))/exp(y(12));
residual(36) = (-exp(y(50)))+T455/(1-exp(y(22)));
residual(37) = (-exp(y(21)))+exp(y(50))^((1-params(10))/params(20));
residual(38) = (-exp(y(22)))+0.5+0.5*erf(log(exp(y(16)))/(params(9)*1.414213562373095));
residual(39) = (-exp(y(23)))+T475;
residual(40) = (-exp(y(51)))+exp(y(23))*T478^params(21);
residual(41) = (-exp(y(24)))+T487;
residual(42) = y(64)+(-exp(y(26)))+exp(y(25));
residual(43) = exp(y(24))-exp(y(31));
residual(44) = exp(y(10))-exp(y(53))-params(23)*(1-exp(y(11)));
residual(45) = (-exp(y(49)))+exp(y(10))^(-params(1));
residual(46) = T182-exp(y(91));
residual(47) = (-y(55))+params(3)*y(8)-x(it_, 1);
residual(48) = (-y(63))+params(76);
residual(49) = (-y(64))+params(77);
residual(50) = (-y(65))+params(78);
residual(51) = (-y(66))+(1-params(24))*log(params(81))+params(24)*y(9)+x(it_, 2);
residual(52) = (-y(67))+params(31)+x(it_, 3);
residual(53) = (-y(68))+params(30)+x(it_, 4);
residual(54) = (1-exp(y(22)))*(1-params(5))*params(13)+(1-params(5))*exp(y(22))+params(5)-exp(y(52));
residual(55) = (-exp(y(56)))+exp(y(13))*exp(y(11))+exp(y(1))*exp(y(31))+exp(y(36))*exp(y(37));
residual(56) = (params(18)+y(65))*exp(y(38))-exp(y(54));
residual(57) = (-exp(y(57)))+exp(y(56))/T133;
residual(58) = (-exp(y(58)))+exp(y(53))/T133;
residual(59) = (-exp(y(59)))+exp(y(15))/T133;
residual(60) = (-exp(y(61)))+exp(y(13))/T133;
residual(61) = (-exp(y(62)))+exp(y(10))/T133;
residual(62) = (-exp(y(60)))+exp(y(54))/T133;
residual(63) = (-exp(y(69)))+exp(y(12))/exp(y(20));
residual(64) = T631*(params(17)*exp(y(69))+T636)+y(63)+params(23)-exp(y(70));
residual(65) = (1-params(5))*exp(y(22))+params(5)-exp(y(71));
residual(66) = 1-exp(y(72))-(1-params(13))*(1-exp(y(71)));
residual(67) = (-exp(y(80)))+exp(y(11))*(1-params(5))*exp(y(22));
residual(68) = (-exp(y(73)))+exp(y(11))*exp(y(72))-exp(y(17))*params(5)*exp(y(11));
residual(69) = (-exp(y(74)))+exp(y(17))*exp(y(12))-exp(y(17))*params(5)*exp(y(11));
residual(70) = exp(y(74))-exp(y(75))-exp(y(73));
residual(71) = (-exp(y(77)))+T686;
residual(72) = exp(y(12))-exp(y(76))-exp(y(77));
residual(73) = (-exp(y(81)))+exp(y(35))/T133;
residual(74) = (-exp(y(82)))+exp(y(36))/T133;
residual(75) = (-exp(y(83)))+exp(y(29))/T133;
residual(76) = (-exp(y(84)))+exp(y(11))*(1-y(67))*exp(y(13));
residual(77) = (-exp(y(85)))+exp(y(14))*(1-y(68))*exp(y(31));
residual(78) = (-exp(y(86)))+exp(y(37))*(exp(y(36))+exp(y(35)));
residual(79) = (-exp(y(87)))+exp(y(35))*(exp(y(37))+exp(y(38)));
residual(80) = exp(y(11))*y(67)*exp(y(13))-exp(y(14))*y(68)*exp(y(31))-exp(y(66))+exp(y(86))+exp(y(85))+exp(y(84))-exp(y(88));
residual(81) = exp(y(15))+exp(y(87))+exp(y(53))-exp(y(89));
residual(82) = (-exp(y(90)))+(exp(y(100))+exp(y(101)))/exp(y(35));
residual(83) = exp(y(66))-exp(y(92))-exp(y(11))*y(67)*exp(y(13))-exp(y(14))*y(68)*exp(y(31));
if nargout >= 2,
  g1 = zeros(83, 108);

  %
  % Jacobian matrix
  %

  g1(1,10)=(-1);
  g1(1,47)=1;
  g1(2,47)=(-1);
  g1(2,48)=1;
  g1(2,102)=(-params(2));
  g1(3,3)=(1-params(5))*(1-exp(y(22)))*exp(y(3))*exp(y(6));
  g1(3,22)=exp(y(7))*(1-params(5))*(-exp(y(22)))+exp(y(6))*exp(y(3))*(1-params(5))*(-exp(y(22)));
  g1(3,6)=(1-params(5))*(1-exp(y(22)))*exp(y(3))*exp(y(6));
  g1(3,7)=(1-params(5))*(1-exp(y(22)))*exp(y(7));
  g1(3,45)=(-exp(y(45)));
  g1(4,17)=(-((-params(17))*exp(y(17))))/(exp(y(17))*exp(y(17)));
  g1(4,94)=(1-params(5))*(1-params(13))*T53*(exp(y(95))*(-exp(y(94)))-exp(y(94))*y(64));
  g1(4,95)=(1-params(5))*(1-params(13))*T53*(1-exp(y(94)))*exp(y(95));
  g1(4,49)=((1-exp(y(94)))*exp(y(95))-exp(y(94))*y(64))*(1-params(5))*(1-params(13))*T1067;
  g1(4,103)=(1-params(5))*(1-params(13))*T53*((1-exp(y(94)))*exp(y(95))-exp(y(94))*y(64));
  g1(4,64)=(1-params(5))*(1-params(13))*T53*(-exp(y(94)));
  g1(5,17)=(-((-(params(17)*exp(y(17))))/(exp(y(17))*exp(y(17)))));
  g1(5,29)=exp(y(29));
  g1(5,51)=(-exp(y(51)));
  g1(5,64)=(-1);
  g1(6,26)=(-exp(y(26)));
  g1(6,27)=T89;
  g1(6,67)=(1-params(6))/params(6)*exp(y(27))*1/((1-y(67))*(1-y(67)));
  g1(7,13)=exp(y(13));
  g1(7,23)=(-(params(6)*exp(y(23))));
  g1(7,29)=(-exp(y(29)));
  g1(7,51)=(-((-exp(y(51)))*params(6)));
  g1(8,11)=T116*exp(y(11))*getPowerDeriv(exp(y(11)),1-params(10),1);
  g1(8,1)=T120*exp(y(55))*exp(y(21))^params(20)*exp(y(1))*getPowerDeriv(exp(y(1)),params(10),1);
  g1(8,21)=T120*exp(y(1))^params(10)*exp(y(55))*exp(y(21))*getPowerDeriv(exp(y(21)),params(20),1);
  g1(8,43)=(-exp(y(43)));
  g1(8,55)=T116*T120;
  g1(9,17)=(-(params(17)*exp(y(17))))/(exp(y(17))*exp(y(17)));
  g1(9,79)=(-exp(y(79)));
  g1(10,13)=(-(exp(y(45))*exp(y(13))));
  g1(10,22)=(-(((1-exp(y(22)))*y(64)*exp(y(45))*exp(y(22))-y(64)*exp(y(45))*exp(y(22))*(-exp(y(22))))/((1-exp(y(22)))*(1-exp(y(22))))));
  g1(10,24)=(-(exp(y(24))*exp(y(46))));
  g1(10,36)=(-exp(y(36)));
  g1(10,39)=T133*exp(y(42));
  g1(10,42)=T133*exp(y(42));
  g1(10,44)=(-(params(17)*exp(y(44))));
  g1(10,45)=(-(exp(y(45))*exp(y(13))))-y(64)*exp(y(45))*exp(y(22))/(1-exp(y(22)));
  g1(10,46)=(-(exp(y(24))*exp(y(46))));
  g1(10,64)=(-(exp(y(45))*exp(y(22))/(1-exp(y(22)))));
  g1(11,17)=params(17)*T914;
  g1(11,35)=(-exp(y(35)));
  g1(11,44)=params(17)*exp(y(44));
  g1(11,45)=params(17)*T162;
  g1(11,65)=1;
  g1(12,37)=(-(exp(y(43))*exp(y(37))))/(exp(y(37))*exp(y(37)));
  g1(12,42)=(-exp(y(42)));
  g1(12,43)=exp(y(43))/exp(y(37));
  g1(13,32)=exp(y(41))*exp(y(32));
  g1(13,39)=(-T133);
  g1(13,41)=exp(y(41))*exp(y(32));
  g1(14,35)=(-exp(y(35)));
  g1(14,100)=params(2)*(1-params(13))*T182*exp(y(100));
  g1(14,101)=params(2)*(1-params(13))*T182*exp(y(101));
  g1(14,49)=(exp(y(100))+exp(y(101)))*params(2)*(1-params(13))*T1072;
  g1(14,103)=params(2)*(1-params(13))*T182*(exp(y(100))+exp(y(101)));
  g1(15,4)=(1-params(13))*exp(y(4));
  g1(15,37)=(-exp(y(37)));
  g1(15,5)=(1-params(13))*exp(y(5));
  g1(16,37)=T133*T209*(exp(y(37))*params(14)*params(15)*(-exp(y(37)))*.5-.5*(params(14)-exp(y(37)))*exp(y(37))*params(14)*params(15))/(exp(y(37))*params(14)*params(15)*exp(y(37))*params(14)*params(15));
  g1(16,39)=T133*T209;
  g1(17,40)=(exp(y(40))*(exp(y(40))-1)-exp(y(40))*exp(y(40)))/((exp(y(40))-1)*(exp(y(40))-1));
  g1(17,41)=(-exp(y(41)));
  g1(18,37)=exp(y(37))*params(15);
  g1(18,40)=(-exp(y(40)));
  g1(19,30)=T229;
  g1(19,37)=(-(exp(y(37))*1/T133*exp(y(30))))/(exp(y(37))*exp(y(37)));
  g1(19,39)=exp(y(30))*(-T133)/(T133*T133)/exp(y(37));
  g1(19,42)=(-exp(y(42)));
  g1(20,12)=params(17)*exp(y(12));
  g1(20,15)=exp(y(15));
  g1(20,22)=((1-exp(y(22)))*y(64)*exp(y(45))*exp(y(22))*exp(y(37))-y(64)*exp(y(45))*exp(y(22))*exp(y(37))*(-exp(y(22))))/((1-exp(y(22)))*(1-exp(y(22))));
  g1(20,30)=(-exp(y(30)));
  g1(20,37)=T249;
  g1(20,38)=(params(18)+y(65))*exp(y(38));
  g1(20,45)=T249;
  g1(20,53)=exp(y(53));
  g1(20,64)=exp(y(45))*exp(y(22))*exp(y(37))/(1-exp(y(22)));
  g1(20,65)=exp(y(38));
  g1(20,66)=exp(y(66));
  g1(21,1)=exp(y(1))*(1-params(19));
  g1(21,14)=(-exp(y(14)));
  g1(21,15)=exp(y(15))*T267;
  g1(21,34)=exp(y(15))*(-(params(12)/2*2*y(34)));
  g1(22,97)=T53*exp(y(97))*(1-y(68));
  g1(22,33)=(-exp(y(33)));
  g1(22,98)=T53*(1-params(19))*exp(y(98));
  g1(22,49)=(exp(y(97))*(1-y(68))+(1-params(19))*exp(y(98)))*T1067;
  g1(22,103)=T53*(exp(y(97))*(1-y(68))+(1-params(19))*exp(y(98)));
  g1(22,68)=T53*(-exp(y(97)));
  g1(23,2)=exp(y(33))*(-(params(12)*y(34)*T864));
  g1(23,15)=exp(y(33))*(-(params(12)*y(34)*T289))+exp(y(98))*T53*params(12)*y(99)*(-(exp(y(15))*exp(y(93))))/(exp(y(15))*exp(y(15)))*2*T299;
  g1(23,93)=exp(y(98))*T53*params(12)*y(99)*T299*2*T299;
  g1(23,33)=T292;
  g1(23,98)=T302;
  g1(23,34)=exp(y(33))*((-(params(12)/2*2*y(34)))-params(12)*T289);
  g1(23,99)=exp(y(98))*T53*params(12)*T299^2;
  g1(23,49)=y(99)*T299^2*exp(y(98))*params(12)*T1067;
  g1(23,103)=T302;
  g1(24,2)=T864;
  g1(24,15)=T289;
  g1(24,34)=(-1);
  g1(25,49)=(-exp(y(49)));
  g1(25,103)=params(2)*exp(y(103))*(1+exp(y(78)));
  g1(25,78)=params(2)*exp(y(103))*exp(y(78));
  g1(26,13)=(-exp(y(13)));
  g1(26,94)=(1-params(5))*(1-params(13))*T53*(exp(y(95))*(-exp(y(94)))-exp(y(94))*y(104));
  g1(26,23)=exp(y(23));
  g1(26,25)=(-exp(y(25)));
  g1(26,95)=(1-params(5))*(1-params(13))*T53*(1-exp(y(94)))*exp(y(95));
  g1(26,49)=((1-exp(y(94)))*exp(y(95))-exp(y(94))*y(104))*(1-params(5))*(1-params(13))*T1067;
  g1(26,103)=(1-params(5))*(1-params(13))*T53*((1-exp(y(94)))*exp(y(95))-exp(y(94))*y(104));
  g1(26,104)=(1-params(5))*(1-params(13))*T53*(-exp(y(94)));
  g1(27,13)=(1-y(67))*exp(y(13));
  g1(27,94)=exp(y(96))*(1-params(5))*(1-params(13))*T53*(-exp(y(94)));
  g1(27,27)=(-exp(y(27)));
  g1(27,96)=(1-params(5))*(1-params(13))*T53*(1-exp(y(94)))*exp(y(96));
  g1(27,28)=(-exp(y(28)));
  g1(27,49)=exp(y(96))*(1-exp(y(94)))*(1-params(5))*(1-params(13))*T1067;
  g1(27,103)=(1-params(5))*(1-params(13))*T53*(1-exp(y(94)))*exp(y(96));
  g1(27,67)=(-exp(y(13)));
  g1(28,19)=T351;
  g1(28,94)=exp(y(96))*T182*params(2)*(1-params(5))*(1-params(13))*exp(y(19))*(-exp(y(94)));
  g1(28,96)=T351;
  g1(28,28)=(-exp(y(28)));
  g1(28,49)=exp(y(96))*(1-exp(y(94)))*exp(y(19))*params(2)*(1-params(5))*(1-params(13))*T1072;
  g1(28,103)=T351;
  g1(28,63)=1;
  g1(29,12)=(-exp(y(12)));
  g1(29,17)=(-(exp(y(17))*exp(y(45))*exp(y(38))))/(exp(y(17))*exp(y(17)));
  g1(29,37)=exp(y(44))*exp(y(37));
  g1(29,38)=T359+exp(y(44))*exp(y(38));
  g1(29,44)=exp(y(44))*(exp(y(37))+exp(y(38)));
  g1(29,45)=T359;
  g1(30,11)=exp(y(11))/exp(y(37));
  g1(30,37)=(-(exp(y(11))*exp(y(37))))/(exp(y(37))*exp(y(37)));
  g1(30,45)=(-exp(y(45)));
  g1(31,1)=exp(y(1))/exp(y(37));
  g1(31,37)=(-(exp(y(1))*exp(y(37))))/(exp(y(37))*exp(y(37)));
  g1(31,46)=(-exp(y(46)));
  g1(32,12)=exp(y(20))^params(7)*params(16)*exp(y(12))*getPowerDeriv(exp(y(12)),1-params(7),1);
  g1(32,18)=(-exp(y(18)));
  g1(32,20)=params(16)*exp(y(12))^(1-params(7))*exp(y(20))*getPowerDeriv(exp(y(20)),params(7),1);
  g1(33,11)=(-exp(y(11)));
  g1(33,20)=(-exp(y(20)));
  g1(34,18)=exp(y(18))/exp(y(20));
  g1(34,19)=(-exp(y(19)));
  g1(34,20)=(-(exp(y(18))*exp(y(20))))/(exp(y(20))*exp(y(20)));
  g1(35,12)=(-(exp(y(12))*exp(y(18))))/(exp(y(12))*exp(y(12)));
  g1(35,17)=(-exp(y(17)));
  g1(35,18)=exp(y(18))/exp(y(12));
  g1(36,16)=T453*T417*0.7071067811865475/params(9)*((-1)+params(10))/((-1)+params(10))*2/(exp(T433^2)*1.772453850905516)/params(11)^0.5/(1-exp(y(22)));
  g1(36,22)=(-(T455*(-exp(y(22)))))/((1-exp(y(22)))*(1-exp(y(22))));
  g1(36,50)=(-exp(y(50)));
  g1(37,21)=(-exp(y(21)));
  g1(37,50)=exp(y(50))*getPowerDeriv(exp(y(50)),(1-params(10))/params(20),1);
  g1(38,16)=0.5*1/(params(9)*1.414213562373095)*2/(1.772453850905516*exp((log(exp(y(16)))/(params(9)*1.414213562373095))^2));
  g1(38,22)=(-exp(y(22)));
  g1(39,11)=(-(exp(y(11))*exp(y(43))*(1-params(10))*exp(y(32))))/(exp(y(11))*exp(y(11)));
  g1(39,23)=(-exp(y(23)));
  g1(39,32)=T475;
  g1(39,43)=T475;
  g1(40,16)=exp(y(23))*T478*getPowerDeriv(T478,params(21),1);
  g1(40,21)=exp(y(23))*getPowerDeriv(T478,params(21),1)*(-(exp(y(21))*exp(y(16))))/(exp(y(21))*exp(y(21)));
  g1(40,23)=exp(y(23))*T478^params(21);
  g1(40,51)=(-exp(y(51)));
  g1(41,1)=(-(exp(y(1))*exp(y(43))*params(10)*exp(y(32))))/(exp(y(1))*exp(y(1)));
  g1(41,24)=(-exp(y(24)));
  g1(41,32)=T487;
  g1(41,43)=T487;
  g1(42,25)=exp(y(25));
  g1(42,26)=(-exp(y(26)));
  g1(42,64)=1;
  g1(43,24)=exp(y(24));
  g1(43,31)=(-exp(y(31)));
  g1(44,10)=exp(y(10));
  g1(44,11)=(-(params(23)*(-exp(y(11)))));
  g1(44,53)=(-exp(y(53)));
  g1(45,10)=exp(y(10))*getPowerDeriv(exp(y(10)),(-params(1)),1);
  g1(45,49)=(-exp(y(49)));
  g1(46,49)=T1072;
  g1(46,103)=T182;
  g1(46,91)=(-exp(y(91)));
  g1(47,8)=params(3);
  g1(47,55)=(-1);
  g1(47,105)=(-1);
  g1(48,63)=(-1);
  g1(49,64)=(-1);
  g1(50,65)=(-1);
  g1(51,9)=params(24);
  g1(51,66)=(-1);
  g1(51,106)=1;
  g1(52,67)=(-1);
  g1(52,107)=1;
  g1(53,68)=(-1);
  g1(53,108)=1;
  g1(54,22)=(1-params(5))*exp(y(22))+(-exp(y(22)))*(1-params(5))*params(13);
  g1(54,52)=(-exp(y(52)));
  g1(55,11)=exp(y(13))*exp(y(11));
  g1(55,13)=exp(y(13))*exp(y(11));
  g1(55,1)=exp(y(1))*exp(y(31));
  g1(55,31)=exp(y(1))*exp(y(31));
  g1(55,36)=exp(y(36))*exp(y(37));
  g1(55,37)=exp(y(36))*exp(y(37));
  g1(55,56)=(-exp(y(56)));
  g1(56,38)=(params(18)+y(65))*exp(y(38));
  g1(56,54)=(-exp(y(54)));
  g1(56,65)=exp(y(38));
  g1(57,39)=(-(T133*exp(y(56))))/(T133*T133);
  g1(57,56)=exp(y(56))/T133;
  g1(57,57)=(-exp(y(57)));
  g1(58,39)=(-(T133*exp(y(53))))/(T133*T133);
  g1(58,53)=exp(y(53))/T133;
  g1(58,58)=(-exp(y(58)));
  g1(59,15)=exp(y(15))/T133;
  g1(59,39)=(-(T133*exp(y(15))))/(T133*T133);
  g1(59,59)=(-exp(y(59)));
  g1(60,13)=exp(y(13))/T133;
  g1(60,39)=(-(exp(y(13))*T133))/(T133*T133);
  g1(60,61)=(-exp(y(61)));
  g1(61,10)=exp(y(10))/T133;
  g1(61,39)=(-(exp(y(10))*T133))/(T133*T133);
  g1(61,62)=(-exp(y(62)));
  g1(62,39)=(-(T133*exp(y(54))))/(T133*T133);
  g1(62,54)=exp(y(54))/T133;
  g1(62,60)=(-exp(y(60)));
  g1(63,12)=exp(y(12))/exp(y(20));
  g1(63,20)=(-(exp(y(12))*exp(y(20))))/(exp(y(20))*exp(y(20)));
  g1(63,69)=(-exp(y(69)));
  g1(64,19)=T631*T636;
  g1(64,49)=T631*exp(y(19))*y(64)*(-(exp(y(49))*exp(y(103))*params(2)*(1-params(5))*(1-params(13))))/(exp(y(49))*exp(y(49)));
  g1(64,103)=T631*T636;
  g1(64,63)=1;
  g1(64,64)=T631*exp(y(19))*exp(y(103))*params(2)*(1-params(5))*(1-params(13))/exp(y(49));
  g1(64,69)=T631*params(17)*exp(y(69));
  g1(64,70)=(-exp(y(70)));
  g1(65,22)=(1-params(5))*exp(y(22));
  g1(65,71)=(-exp(y(71)));
  g1(66,71)=(-((1-params(13))*(-exp(y(71)))));
  g1(66,72)=(-exp(y(72)));
  g1(67,11)=exp(y(11))*(1-params(5))*exp(y(22));
  g1(67,22)=exp(y(11))*(1-params(5))*exp(y(22));
  g1(67,80)=(-exp(y(80)));
  g1(68,11)=exp(y(11))*exp(y(72))-exp(y(17))*params(5)*exp(y(11));
  g1(68,17)=(-(exp(y(17))*params(5)*exp(y(11))));
  g1(68,72)=exp(y(11))*exp(y(72));
  g1(68,73)=(-exp(y(73)));
  g1(69,11)=(-(exp(y(17))*params(5)*exp(y(11))));
  g1(69,12)=exp(y(17))*exp(y(12));
  g1(69,17)=exp(y(17))*exp(y(12))-exp(y(17))*params(5)*exp(y(11));
  g1(69,74)=(-exp(y(74)));
  g1(70,73)=(-exp(y(73)));
  g1(70,74)=exp(y(74));
  g1(70,75)=(-exp(y(75)));
  g1(71,17)=exp(y(38))*T914;
  g1(71,38)=T686;
  g1(71,44)=exp(y(44))*exp(y(38));
  g1(71,45)=T162*exp(y(38));
  g1(71,77)=(-exp(y(77)));
  g1(72,12)=exp(y(12));
  g1(72,76)=(-exp(y(76)));
  g1(72,77)=(-exp(y(77)));
  g1(73,35)=exp(y(35))/T133;
  g1(73,39)=(-(T133*exp(y(35))))/(T133*T133);
  g1(73,81)=(-exp(y(81)));
  g1(74,36)=exp(y(36))/T133;
  g1(74,39)=(-(exp(y(36))*T133))/(T133*T133);
  g1(74,82)=(-exp(y(82)));
  g1(75,29)=exp(y(29))/T133;
  g1(75,39)=(-(exp(y(29))*T133))/(T133*T133);
  g1(75,83)=(-exp(y(83)));
  g1(76,11)=exp(y(11))*(1-y(67))*exp(y(13));
  g1(76,13)=exp(y(11))*(1-y(67))*exp(y(13));
  g1(76,67)=exp(y(11))*(-exp(y(13)));
  g1(76,84)=(-exp(y(84)));
  g1(77,14)=exp(y(14))*(1-y(68))*exp(y(31));
  g1(77,31)=exp(y(14))*(1-y(68))*exp(y(31));
  g1(77,68)=exp(y(14))*(-exp(y(31)));
  g1(77,85)=(-exp(y(85)));
  g1(78,35)=exp(y(35))*exp(y(37));
  g1(78,36)=exp(y(36))*exp(y(37));
  g1(78,37)=exp(y(37))*(exp(y(36))+exp(y(35)));
  g1(78,86)=(-exp(y(86)));
  g1(79,35)=exp(y(35))*(exp(y(37))+exp(y(38)));
  g1(79,37)=exp(y(35))*exp(y(37));
  g1(79,38)=exp(y(35))*exp(y(38));
  g1(79,87)=(-exp(y(87)));
  g1(80,11)=exp(y(11))*y(67)*exp(y(13));
  g1(80,13)=exp(y(11))*y(67)*exp(y(13));
  g1(80,14)=(-(exp(y(14))*y(68)*exp(y(31))));
  g1(80,31)=(-(exp(y(14))*y(68)*exp(y(31))));
  g1(80,66)=(-exp(y(66)));
  g1(80,67)=exp(y(13))*exp(y(11));
  g1(80,68)=(-(exp(y(14))*exp(y(31))));
  g1(80,84)=exp(y(84));
  g1(80,85)=exp(y(85));
  g1(80,86)=exp(y(86));
  g1(80,88)=(-exp(y(88)));
  g1(81,15)=exp(y(15));
  g1(81,53)=exp(y(53));
  g1(81,87)=exp(y(87));
  g1(81,89)=(-exp(y(89)));
  g1(82,35)=(-(exp(y(35))*(exp(y(100))+exp(y(101)))))/(exp(y(35))*exp(y(35)));
  g1(82,100)=exp(y(100))/exp(y(35));
  g1(82,101)=exp(y(101))/exp(y(35));
  g1(82,90)=(-exp(y(90)));
  g1(83,11)=(-(exp(y(11))*y(67)*exp(y(13))));
  g1(83,13)=(-(exp(y(11))*y(67)*exp(y(13))));
  g1(83,14)=(-(exp(y(14))*y(68)*exp(y(31))));
  g1(83,31)=(-(exp(y(14))*y(68)*exp(y(31))));
  g1(83,66)=exp(y(66));
  g1(83,67)=(-(exp(y(13))*exp(y(11))));
  g1(83,68)=(-(exp(y(14))*exp(y(31))));
  g1(83,92)=(-exp(y(92)));
end
if nargout >= 3,
  %
  % Hessian matrix
  %

  g2 = sparse([],[],[],83,11664);
end
if nargout >= 4,
  %
  % Third order derivatives
  %

  g3 = sparse([],[],[],83,1259712);
end
end
